@@ -1,19 +1,24 @@
 package SOAP::WSDL::XSD::Schema;
 use strict;
 use warnings;
-use Class::Std::Storable;
+use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
+use version; our $VERSION = qv('2.00.09');
+
 # child elements
-my %type_of :ATTR(:name<type> :default<[]>);
-my %element_of :ATTR(:name<element> :default<[]>);
+my %attributeGroup_of   :ATTR(:name<attributeGroup>  :default<[]>);
+my %attribute_of        :ATTR(:name<attribute>       :default<[]>);
+my %element_of          :ATTR(:name<element>         :default<[]>);
+my %group_of            :ATTR(:name<group>           :default<[]>);
+my %type_of             :ATTR(:name<type>            :default<[]>);
 
 # attributes
-my %attributeFormDefault_of :ATTR(:name<attributeFormDefault> :default<()>);
-my %blockDefault_of :ATTR(:name<blockDefault> :default<()>);
-my %elementFormDefault_of :ATTR(:name<elementFormDefault> :default<()>);
-my %finalDefault_of :ATTR(:name<finalDefault> :default<()>);
-my %version_of :ATTR(:name<version> :default<()>);
+my %attributeFormDefault_of :ATTR(:name<attributeFormDefault> :default<unqualified>);
+my %blockDefault_of         :ATTR(:name<blockDefault>         :default<()>);
+my %elementFormDefault_of   :ATTR(:name<elementFormDefault>   :default<unqualified>);
+my %finalDefault_of         :ATTR(:name<finalDefault>         :default<()>);
+my %version_of              :ATTR(:name<version>              :default<()>);
 
 # id
 # name
@@ -53,6 +58,8 @@ sub find_element {
     my ($self, @args) = @_;
     my @found_at = grep {
         $_->get_targetNamespace() eq $args[0] &&
+#		warn $_->get_name() . " default NS:" . $_->get_xmlns()->{'#default'} . "\n";
+#		$_->get_xmlns()->{'#default'} eq $args[0] &&
         $_->get_name() eq $args[1]
     }
     @{ $element_of{ ident $self } };
@@ -63,6 +70,7 @@ sub find_type {
     my ($self, @args) = @_;
     my @found_at = grep {
         $_->get_targetNamespace() eq $args[0] &&
+#        $_->get_xmlns()->{'#default'} eq $args[0] &&
         $_->get_name() eq $args[1]
     }
     @{ $type_of{ ident $self } };
